<?php
// Oturum başlatma ve kontrolü
session_start();

// Oturum kontrolü
if (!isset($_SESSION['user_id']) || !isset($_SESSION['username'])) {
    http_response_code(401);
    echo json_encode(['success' => false, 'message' => 'Yetkisiz erişim']);
    exit;
}

// Yalnızca POST isteklerine izin ver
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405);
    echo json_encode(['success' => false, 'message' => 'Geçersiz istek metodu']);
    exit;
}

// Hata ayıklama için
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Gereken dosyaları dahil et
require_once '../config/database.php';
require_once '../classes/Vehicle.php';

// Kullanıcı bilgilerini al
$userId = $_SESSION['user_id'];
$companyId = $_SESSION['company_id'];

// Gelen form verilerini al
$customerId = (int)($_POST['customer_id'] ?? 0);
$plateNumber = trim($_POST['plate_number'] ?? '');
$brand = trim($_POST['brand'] ?? '');
$model = trim($_POST['model'] ?? '');
$year = (int)($_POST['year'] ?? 0);
$color = trim($_POST['color'] ?? '');
$chassisNumber = trim($_POST['chassis_number'] ?? '');
$fuelType = trim($_POST['fuel_type'] ?? '');
$transmission = trim($_POST['transmission'] ?? '');
$mileage = (int)($_POST['mileage'] ?? 0);
$engineSize = trim($_POST['engine_size'] ?? '');
$enginePower = trim($_POST['engine_power'] ?? '');

// Temel veri doğrulama
if ($customerId <= 0 || empty($plateNumber) || empty($brand) || empty($model) || $year <= 0) {
    echo json_encode(['success' => false, 'message' => 'Müşteri, plaka, marka, model ve yıl alanları zorunludur']);
    exit;
}

try {
    // Veritabanı bağlantısı
    $db = new Database();
    $conn = $db->getConnection();

    // Transaction başlat
    $conn->beginTransaction();

    // 1. Adım: Marka kontrolü - Yoksa ekle
    $brandQuery = "SELECT id FROM car_brands WHERE brand_name = :brand_name LIMIT 1";
    $brandStmt = $conn->prepare($brandQuery);
    $brandStmt->bindParam(':brand_name', $brand);
    $brandStmt->execute();

    if ($brandStmt->rowCount() > 0) {
        // Marka varsa, ID'sini al
        $brandRow = $brandStmt->fetch(PDO::FETCH_ASSOC);
        $brandId = $brandRow['id'];
    } else {
        // Marka yoksa, ekle
        $insertBrandQuery = "INSERT INTO car_brands (brand_name, status, created_at) VALUES (:brand_name, 'active', NOW())";
        $insertBrandStmt = $conn->prepare($insertBrandQuery);
        $insertBrandStmt->bindParam(':brand_name', $brand);
        $insertBrandStmt->execute();
        $brandId = $conn->lastInsertId();
    }

    // 2. Adım: Model kontrolü - Yoksa ekle
    $modelQuery = "SELECT id FROM car_models WHERE model_name = :model_name AND brand_id = :brand_id LIMIT 1";
    $modelStmt = $conn->prepare($modelQuery);
    $modelStmt->bindParam(':model_name', $model);
    $modelStmt->bindParam(':brand_id', $brandId);
    $modelStmt->execute();

    if ($modelStmt->rowCount() > 0) {
        // Model varsa, ID'sini al
        $modelRow = $modelStmt->fetch(PDO::FETCH_ASSOC);
        $modelId = $modelRow['id'];
    } else {
        // Model yoksa, ekle
        $insertModelQuery = "INSERT INTO car_models (brand_id, model_name, status, created_at) VALUES (:brand_id, :model_name, 'active', NOW())";
        $insertModelStmt = $conn->prepare($insertModelQuery);
        $insertModelStmt->bindParam(':brand_id', $brandId);
        $insertModelStmt->bindParam(':model_name', $model);
        $insertModelStmt->execute();
        $modelId = $conn->lastInsertId();
    }

    // Doğrulama için log
    error_log("Marka ID: " . $brandId . ", Model ID: " . $modelId);

    // 3. Adım: Araç ekleme
    $sql = "INSERT INTO vehicles (
        company_id, customer_id, brand_id, model_id, plate_number, 
        vin_number, year, color, fuel_type, transmission, 
        mileage, engine_size, engine_power, created_at
    ) VALUES (
        :company_id, :customer_id, :brand_id, :model_id, :plate_number,
        :vin_number, :year, :color, :fuel_type, :transmission,
        :mileage, :engine_size, :engine_power, NOW()
    )";

    $stmt = $conn->prepare($sql);

    // Parametreleri bağlama
    $stmt->bindValue(':company_id', $companyId, PDO::PARAM_INT);
    $stmt->bindValue(':customer_id', $customerId, PDO::PARAM_INT);
    $stmt->bindValue(':brand_id', $brandId, PDO::PARAM_INT);
    $stmt->bindValue(':model_id', $modelId, PDO::PARAM_INT);
    $stmt->bindValue(':plate_number', $plateNumber);
    $stmt->bindValue(':vin_number', $chassisNumber);
    $stmt->bindValue(':year', $year, PDO::PARAM_INT);
    $stmt->bindValue(':color', $color);
    $stmt->bindValue(':fuel_type', $fuelType);
    $stmt->bindValue(':transmission', $transmission);
    $stmt->bindValue(':mileage', $mileage, PDO::PARAM_INT);
    $stmt->bindValue(':engine_size', $engineSize);
    $stmt->bindValue(':engine_power', $enginePower);

    // Sorguyu çalıştır
    if ($stmt->execute()) {
        $vehicleId = $conn->lastInsertId();

        // Transaction'ı tamamla
        $conn->commit();

        // Başarılı yanıt döndür
        echo json_encode([
            'success' => true,
            'vehicle_id' => $vehicleId,
            'vehicle_name' => $brand . ' ' . $model . ' (' . $plateNumber . ')'
        ]);
    } else {
        // Hata durumunda rollback
        $conn->rollBack();

        // Hata yanıtı döndür
        $errorInfo = $stmt->errorInfo();
        error_log("SQL Error: " . print_r($errorInfo, true));
        echo json_encode(['success' => false, 'message' => 'Araç oluşturulurken bir hata oluştu: ' . $errorInfo[2]]);
    }
} catch (PDOException $e) {
    // Hata durumunda rollback
    if (isset($conn)) {
        $conn->rollBack();
    }

    error_log("PDO Exception: " . $e->getMessage());
    echo json_encode(['success' => false, 'message' => 'Veritabanı hatası: ' . $e->getMessage()]);
} catch (Exception $e) {
    // Hata durumunda rollback
    if (isset($conn)) {
        $conn->rollBack();
    }

    error_log("General Exception: " . $e->getMessage());
    echo json_encode(['success' => false, 'message' => 'Sistem hatası: ' . $e->getMessage()]);
}
?>