<?php
// Oturum başlatma
session_start();

// Veritabanı bağlantısı ve yapılandırma dosyası
require_once '../config/database.php';
require_once '../classes/User.php';

// CORS kontrolü ve güvenlik ayarları
header("Access-Control-Allow-Origin: *");
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

// POST verileri yoksa işlemi sonlandır
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['success' => false, 'message' => 'Geçersiz istek metodu']);
    exit;
}

// POST verilerini alma
$data = json_decode(file_get_contents("php://input"), true);

// Eğer JSON veri yoksa, normal POST verilerini kullan
if (empty($data)) {
    $data = $_POST;
}

// Kullanıcı adı ve şifre kontrolü
if (empty($data['username']) || empty($data['password'])) {
    echo json_encode(['success' => false, 'message' => 'Kullanıcı adı ve şifre zorunludur']);
    exit;
}

// XSS ve SQL Injection koruması
$username = htmlspecialchars(strip_tags(trim($data['username'])));
$password = trim($data['password']);
$remember = isset($data['remember']) ? (bool)$data['remember'] : false;

try {
    // Veritabanı bağlantısı
    $db = new Database();
    $conn = $db->getConnection();

    // Kullanıcı nesnesi oluşturma
    $user = new User($conn);

    // Kullanıcı girişi doğrulama
    $userData = $user->login($username, $password);

    if ($userData) {
        // Kullanıcı durumu kontrolü
        if ($userData['status'] != 'active') {
            echo json_encode([
                'success' => false,
                'message' => 'Hesabınız aktif değil. Lütfen yöneticinizle iletişime geçin.'
            ]);
            exit;
        }

        // Oturum verilerini ayarlama
        $_SESSION['user_id'] = $userData['id'];
        $_SESSION['username'] = $userData['username'];
        $_SESSION['user_role'] = $userData['role'];
        $_SESSION['company_id'] = $userData['company_id'];
        $_SESSION['last_activity'] = time();

        // Beni hatırla seçeneği için cookie ayarlama
        if ($remember) {
            // Güvenli token oluşturma
            $token = bin2hex(random_bytes(32));
            $expiry = time() + (30 * 24 * 60 * 60); // 30 gün

            // Token'ı veritabanına kaydetme
            $user->saveRememberToken($userData['id'], $token, $expiry);

            // Cookie ayarlama
            setcookie('remember_token', $token, $expiry, '/', '', true, true);
        }

        // Giriş başarılı mesajı
        echo json_encode([
            'success' => true,
            'message' => 'Giriş başarılı',
            'redirect_url' => 'dashboard.php',
            'user' => [
                'id' => $userData['id'],
                'username' => $userData['username'],
                'role' => $userData['role'],
                'company_id' => $userData['company_id']
            ]
        ]);

        // Giriş logunu kaydetme
        $user->logActivity($userData['id'], 'login', 'Kullanıcı sisteme giriş yaptı');

    } else {
        // Giriş başarısız mesajı
        echo json_encode([
            'success' => false,
            'message' => 'Kullanıcı adı veya şifre hatalı'
        ]);
    }
} catch (Exception $e) {
    // Hata durumunda
    echo json_encode([
        'success' => false,
        'message' => 'Sistemde bir hata oluştu: ' . $e->getMessage()
    ]);
}
?>