<?php
// Oturum başlatma
session_start();

// Veritabanı bağlantısı ve yapılandırma dosyası
require_once '../config/database.php';
require_once '../classes/User.php';

// CORS kontrolü ve güvenlik ayarları
header("Access-Control-Allow-Origin: *");
header("Content-Type: application/json; charset=UTF-8");
header("Access-Control-Allow-Methods: POST");
header("Access-Control-Max-Age: 3600");
header("Access-Control-Allow-Headers: Content-Type, Access-Control-Allow-Headers, Authorization, X-Requested-With");

// POST verileri yoksa işlemi sonlandır
if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    http_response_code(405); // Method Not Allowed
    echo json_encode(['success' => false, 'message' => 'Geçersiz istek metodu']);
    exit;
}

// POST verilerini alma
$data = json_decode(file_get_contents("php://input"), true);

// Eğer JSON veri yoksa, normal POST verilerini kullan
if (empty($data)) {
    $data = $_POST;
}

// Kullanıcı ID ve şifre kontrolü
if (empty($data['user_id']) || empty($data['new_password'])) {
    echo json_encode(['success' => false, 'message' => 'Kullanıcı ID ve yeni şifre zorunludur']);
    exit;
}

// XSS ve SQL Injection koruması
$userId = filter_var($data['user_id'], FILTER_SANITIZE_NUMBER_INT);
$newPassword = htmlspecialchars(trim($data['new_password']));

// Şifre uzunluğu kontrolü
if (strlen($newPassword) < 8) {
    echo json_encode(['success' => false, 'message' => 'Şifre en az 8 karakter olmalıdır']);
    exit;
}

try {
    // Veritabanı bağlantısı
    $db = new Database();
    $conn = $db->getConnection();

    // Kullanıcı nesnesi oluşturma
    $user = new User($conn);

    // Kullanıcı mevcut mu kontrol etme
    if ($user->readOne($userId)) {
        // Kullanıcının durumu aktif mi kontrol etme
        if ($user->status != 'active') {
            echo json_encode([
                'success' => false,
                'message' => 'Bu hesap aktif değil. Lütfen yöneticinizle iletişime geçin.'
            ]);
            exit;
        }

        // Şifreyi güncelleme
        if ($user->updatePassword($newPassword)) {
            // Başarılı güncelleme mesajı
            echo json_encode([
                'success' => true,
                'message' => 'Şifreniz başarıyla güncellendi! Yeni şifrenizle giriş yapabilirsiniz.'
            ]);

            // Kullanıcı aktivitesini kaydetme
            $user->logActivity($userId, 'password_reset', 'Kullanıcı şifresini yeniledi');

        } else {
            // Güncelleme hatası mesajı
            echo json_encode([
                'success' => false,
                'message' => 'Şifre güncellenirken bir hata oluştu. Lütfen tekrar deneyin.'
            ]);
        }
    } else {
        // Kullanıcı bulunamadı mesajı
        echo json_encode([
            'success' => false,
            'message' => 'Belirtilen ID ile bir kullanıcı bulunamadı.'
        ]);
    }
} catch (Exception $e) {
    // Hata durumunda
    error_log("Şifre sıfırlama hatası: " . $e->getMessage());
    echo json_encode([
        'success' => false,
        'message' => 'Sistemde bir hata oluştu: ' . $e->getMessage()
    ]);
}
?>