<?php
/**
 * Müşteri işlemleri sınıfı
 */
class Customer {
    // Veritabanı bağlantısı ve tablo
    private $conn;
    private $table_name = "customers";

    // Müşteri özellikleri
    public $id;
    public $company_id;
    public $first_name;
    public $last_name;
    public $identity_number;
    public $email;
    public $phone;
    public $address;
    public $city;
    public $status;
    public $created_at;
    public $updated_at;

    /**
     * Sınıf başlatıcı
     *
     * @param PDO $db Veritabanı bağlantısı
     */
    public function __construct($db) {
        $this->conn = $db;
    }

    /**
     * Yeni müşteri oluşturma
     *
     * @return boolean İşlem başarılı mı
     */
    public function create() {
        // SQL sorgusu
        $query = "INSERT INTO " . $this->table_name . "
                  (company_id, first_name, last_name, identity_number, email, phone, address, city, status, created_at)
                  VALUES
                  (:company_id, :first_name, :last_name, :identity_number, :email, :phone, :address, :city, :status, NOW())";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $this->first_name = htmlspecialchars(strip_tags($this->first_name));
        $this->last_name = htmlspecialchars(strip_tags($this->last_name));
        $this->identity_number = htmlspecialchars(strip_tags($this->identity_number));
        $this->email = htmlspecialchars(strip_tags($this->email));
        $this->phone = htmlspecialchars(strip_tags($this->phone));
        $this->address = htmlspecialchars(strip_tags($this->address));
        $this->city = htmlspecialchars(strip_tags($this->city));
        $this->status = htmlspecialchars(strip_tags($this->status));

        // Parametreleri bağlama
        $stmt->bindParam(":company_id", $this->company_id);
        $stmt->bindParam(":first_name", $this->first_name);
        $stmt->bindParam(":last_name", $this->last_name);
        $stmt->bindParam(":identity_number", $this->identity_number);
        $stmt->bindParam(":email", $this->email);
        $stmt->bindParam(":phone", $this->phone);
        $stmt->bindParam(":address", $this->address);
        $stmt->bindParam(":city", $this->city);
        $stmt->bindParam(":status", $this->status);

        // Sorguyu çalıştırma
        if ($stmt->execute()) {
            $this->id = $this->conn->lastInsertId();
            return true;
        }

        return false;
    }

    /**
     * Müşteriyi ID ile bulma
     *
     * @param int $id Müşteri ID
     * @return boolean İşlem başarılı mı
     */
    public function readOne($id) {
        // SQL sorgusu
        $query = "SELECT * FROM " . $this->table_name . " WHERE id = :id LIMIT 1";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // ID parametresini bağlama
        $stmt->bindParam(':id', $id);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Müşteri bulundu mu kontrol etme
        if ($stmt->rowCount() > 0) {
            // Müşteri verilerini alma
            $row = $stmt->fetch(PDO::FETCH_ASSOC);

            // Müşteri özelliklerini ayarlama
            $this->id = $row['id'];
            $this->company_id = $row['company_id'];
            $this->first_name = $row['first_name'];
            $this->last_name = $row['last_name'];
            $this->identity_number = $row['identity_number'];
            $this->email = $row['email'];
            $this->phone = $row['phone'];
            $this->address = $row['address'];
            $this->city = $row['city'];
            $this->status = $row['status'];
            $this->created_at = $row['created_at'];
            $this->updated_at = $row['updated_at'];

            return true;
        }

        return false;
    }

    /**
     * Müşteri bilgilerini güncelleme
     *
     * @return boolean İşlem başarılı mı
     */
    public function update() {
        // SQL sorgusu
        $query = "UPDATE " . $this->table_name . "
                  SET first_name = :first_name,
                      last_name = :last_name,
                      identity_number = :identity_number,
                      email = :email,
                      phone = :phone,
                      address = :address,
                      city = :city,
                      status = :status,
                      updated_at = NOW()
                  WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $this->first_name = htmlspecialchars(strip_tags($this->first_name));
        $this->last_name = htmlspecialchars(strip_tags($this->last_name));
        $this->identity_number = htmlspecialchars(strip_tags($this->identity_number));
        $this->email = htmlspecialchars(strip_tags($this->email));
        $this->phone = htmlspecialchars(strip_tags($this->phone));
        $this->address = htmlspecialchars(strip_tags($this->address));
        $this->city = htmlspecialchars(strip_tags($this->city));
        $this->status = htmlspecialchars(strip_tags($this->status));

        // Parametreleri bağlama
        $stmt->bindParam(":id", $this->id);
        $stmt->bindParam(":first_name", $this->first_name);
        $stmt->bindParam(":last_name", $this->last_name);
        $stmt->bindParam(":identity_number", $this->identity_number);
        $stmt->bindParam(":email", $this->email);
        $stmt->bindParam(":phone", $this->phone);
        $stmt->bindParam(":address", $this->address);
        $stmt->bindParam(":city", $this->city);
        $stmt->bindParam(":status", $this->status);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Müşteri silme
     *
     * @return boolean İşlem başarılı mı
     */
    public function delete() {
        // SQL sorgusu
        $query = "DELETE FROM " . $this->table_name . " WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // ID parametresini bağlama
        $stmt->bindParam(":id", $this->id);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Tüm müşterileri listeleme
     *
     * @param int $company_id Şirket ID
     * @param int $limit Limit
     * @param int $offset Offset
     * @param string $search Arama kelimesi
     * @param string $sort_by Sıralama alanı
     * @param string $sort_dir Sıralama yönü
     * @return array Müşteri listesi
     */
    public function getCustomers($company_id, $limit = 10, $offset = 0, $search = null, $sort_by = 'id', $sort_dir = 'DESC') {
        // SQL sorgusu
        $query = "SELECT id, first_name, last_name, identity_number, email, phone, city, status, created_at
                  FROM " . $this->table_name . "
                  WHERE company_id = :company_id";

        $params = [":company_id" => $company_id];

        // Arama parametresi
        if ($search) {
            $query .= " AND (first_name LIKE :search 
                       OR last_name LIKE :search 
                       OR identity_number LIKE :search
                       OR email LIKE :search
                       OR phone LIKE :search
                       OR CONCAT(first_name, ' ', last_name) LIKE :search)";
            $search = "%{$search}%";
            $params[":search"] = $search;
        }

        // Sıralama
        $query .= " ORDER BY {$sort_by} {$sort_dir}";

        // Limit ve offset
        $query .= " LIMIT :limit OFFSET :offset";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        foreach ($params as $key => $value) {
            $stmt->bindValue($key, $value);
        }

        $stmt->bindValue(":limit", (int)$limit, PDO::PARAM_INT);
        $stmt->bindValue(":offset", (int)$offset, PDO::PARAM_INT);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    /**
     * Toplam müşteri sayısını getirme
     *
     * @param int $company_id Şirket ID
     * @param string $search Arama kelimesi
     * @return int Müşteri sayısı
     */
    public function countCustomers($company_id, $search = null) {
        // SQL sorgusu
        $query = "SELECT COUNT(*) as total FROM " . $this->table_name . "
                  WHERE company_id = :company_id";

        $params = [":company_id" => $company_id];

        // Arama parametresi
        if ($search) {
            $query .= " AND (first_name LIKE :search 
                       OR last_name LIKE :search 
                       OR identity_number LIKE :search
                       OR email LIKE :search
                       OR phone LIKE :search
                       OR CONCAT(first_name, ' ', last_name) LIKE :search)";
            $search = "%{$search}%";
            $params[":search"] = $search;
        }

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        foreach ($params as $key => $value) {
            $stmt->bindValue($key, $value);
        }

        // Sorguyu çalıştırma
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);

        // Toplam sayıyı döndürme
        return (int)$row['total'];
    }

    /**
     * Telefon numarasının mevcut olup olmadığını kontrol etme
     *
     * @param string $phone Telefon numarası
     * @param int $exclude_id Hariç tutulacak müşteri ID (güncelleme için)
     * @return boolean Telefon numarası mevcut mu
     */
    public function isPhoneExists($phone, $exclude_id = null) {
        // SQL sorgusu
        $query = "SELECT id FROM " . $this->table_name . " WHERE phone = :phone";

        // Hariç tutulacak ID varsa
        if ($exclude_id) {
            $query .= " AND id != :exclude_id";
        }

        $query .= " LIMIT 1";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(":phone", $phone);

        if ($exclude_id) {
            $stmt->bindParam(":exclude_id", $exclude_id);
        }

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonucu kontrol etme
        return $stmt->rowCount() > 0;
    }

    /**
     * E-posta adresinin mevcut olup olmadığını kontrol etme
     *
     * @param string $email E-posta adresi
     * @param int $exclude_id Hariç tutulacak müşteri ID (güncelleme için)
     * @return boolean E-posta adresi mevcut mu
     */
    public function isEmailExists($email, $exclude_id = null) {
        // E-posta boşsa kontrole gerek yok
        if (empty($email)) {
            return false;
        }

        // SQL sorgusu
        $query = "SELECT id FROM " . $this->table_name . " WHERE email = :email";

        // Hariç tutulacak ID varsa
        if ($exclude_id) {
            $query .= " AND id != :exclude_id";
        }

        $query .= " LIMIT 1";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(":email", $email);

        if ($exclude_id) {
            $stmt->bindParam(":exclude_id", $exclude_id);
        }

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonucu kontrol etme
        return $stmt->rowCount() > 0;
    }

    /**
     * Kimlik numarasının mevcut olup olmadığını kontrol etme
     *
     * @param string $identity_number Kimlik numarası
     * @param int $exclude_id Hariç tutulacak müşteri ID (güncelleme için)
     * @return boolean Kimlik numarası mevcut mu
     */
    public function isIdentityNumberExists($identity_number, $exclude_id = null) {
        // Kimlik numarası boşsa kontrole gerek yok
        if (empty($identity_number)) {
            return false;
        }

        // SQL sorgusu
        $query = "SELECT id FROM " . $this->table_name . " WHERE identity_number = :identity_number";

        // Hariç tutulacak ID varsa
        if ($exclude_id) {
            $query .= " AND id != :exclude_id";
        }

        $query .= " LIMIT 1";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(":identity_number", $identity_number);

        if ($exclude_id) {
            $stmt->bindParam(":exclude_id", $exclude_id);
        }

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonucu kontrol etme
        return $stmt->rowCount() > 0;
    }

    /**
     * Müşterinin araçlarını getirme
     *
     * @param int $customer_id Müşteri ID
     * @return array Araç listesi
     */
    public function getCustomerVehicles($customer_id) {
        // SQL sorgusu
        $query = "SELECT v.id, v.plate_number, v.year, v.color,
                  b.brand_name, m.model_name
                  FROM vehicles v
                  LEFT JOIN car_brands b ON v.brand_id = b.id
                  LEFT JOIN car_models m ON v.model_id = m.id
                  WHERE v.customer_id = :customer_id
                  ORDER BY v.id DESC";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametre bağlama
        $stmt->bindParam(":customer_id", $customer_id);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    /**
     * Müşterinin ekspertizlerini getirme
     *
     * @param int $customer_id Müşteri ID
     * @param int $limit Limit
     * @return array Ekspertiz listesi
     */
    public function getCustomerExpertises($customer_id, $limit = 10) {
        // SQL sorgusu
        $query = "SELECT e.id, e.expertise_code, e.expertise_date, e.status, e.total_score,
                  CONCAT(v.plate_number, ' - ', b.brand_name, ' ', m.model_name) as vehicle_info
                  FROM expertises e
                  LEFT JOIN vehicles v ON e.vehicle_id = v.id
                  LEFT JOIN car_brands b ON v.brand_id = b.id
                  LEFT JOIN car_models m ON v.model_id = m.id
                  WHERE e.customer_id = :customer_id
                  ORDER BY e.expertise_date DESC
                  LIMIT :limit";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(":customer_id", $customer_id);
        $stmt->bindValue(":limit", (int)$limit, PDO::PARAM_INT);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    /**
     * Şehir listesini getirme
     *
     * @return array Şehir listesi
     */
    public function getCities() {
        // SQL sorgusu (müşterilerin bulunduğu şehirlerin listesini getir)
        $query = "SELECT DISTINCT city 
                  FROM " . $this->table_name . "
                  WHERE city IS NOT NULL AND city != ''
                  ORDER BY city ASC";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        $cities = [];
        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            $cities[] = $row['city'];
        }

        return $cities;
    }

    /**
     * Müşteri durumunu güncelleme
     *
     * @param int $id Müşteri ID
     * @param string $status Yeni durum
     * @return boolean İşlem başarılı mı
     */
    public function updateStatus($id, $status) {
        // SQL sorgusu
        $query = "UPDATE " . $this->table_name . "
                  SET status = :status, updated_at = NOW()
                  WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $status = htmlspecialchars(strip_tags($status));

        // Parametreleri bağlama
        $stmt->bindParam(":id", $id);
        $stmt->bindParam(":status", $status);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Müşterinin tam adını alma
     *
     * @return string Müşterinin tam adı
     */
    public function getFullName() {
        return $this->first_name . ' ' . $this->last_name;
    }

    /**
     * Son eklenen müşterileri getirme
     *
     * @param int $company_id Şirket ID
     * @param int $limit Limit
     * @return array Müşteri listesi
     */
    public function getRecentCustomers($company_id, $limit = 5) {
        // SQL sorgusu
        $query = "SELECT id, first_name, last_name, phone, city
                  FROM " . $this->table_name . "
                  WHERE company_id = :company_id
                  ORDER BY created_at DESC
                  LIMIT :limit";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindValue(":company_id", $company_id);
        $stmt->bindValue(":limit", (int)$limit, PDO::PARAM_INT);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
}