<?php
/**
 * Ekspertiz işlemleri sınıfı
 */
class Expertise {
    // Veritabanı bağlantısı ve tablo
    private $conn;
    private $table_name = "expertises";

    // Ekspertiz özellikleri
    public $id;
    public $company_id;
    public $vehicle_id;
    public $customer_id;
    public $expert_id;
    public $template_id;
    public $expertise_code;
    public $expertise_date;
    public $status;
    public $total_score;
    public $notes;
    public $location;
    public $report_url;
    public $created_at;
    public $updated_at;
    public $extra_data; // Eklendi

    /**
     * Sınıf başlatıcı
     *
     * @param PDO $db Veritabanı bağlantısı
     */
    public function __construct($db) {
        $this->conn = $db;
    }

    /**
     * Yeni ekspertiz oluşturma
     *
     * @return boolean İşlem başarılı mı
     */
    public function create() {
        // SQL sorgusu
        $query = "INSERT INTO " . $this->table_name . "
                  (company_id, vehicle_id, customer_id, expert_id, template_id, expertise_code, 
                   expertise_date, status, total_score, notes, extra_data, location, report_url, created_at)
                  VALUES
                  (:company_id, :vehicle_id, :customer_id, :expert_id, :template_id, :expertise_code, 
                   :expertise_date, :status, :total_score, :notes, :extra_data, :location, :report_url, NOW())";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $this->expertise_code = htmlspecialchars(strip_tags($this->expertise_code));
        $this->status = htmlspecialchars(strip_tags($this->status));
        $this->notes = htmlspecialchars(strip_tags($this->notes));
        $this->location = htmlspecialchars(strip_tags($this->location));
        $this->report_url = htmlspecialchars(strip_tags($this->report_url));

        // Parametreleri bağlama
        $stmt->bindParam(":company_id", $this->company_id);
        $stmt->bindParam(":vehicle_id", $this->vehicle_id);
        $stmt->bindParam(":customer_id", $this->customer_id);
        $stmt->bindParam(":expert_id", $this->expert_id);
        $stmt->bindParam(":template_id", $this->template_id);
        $stmt->bindParam(":expertise_code", $this->expertise_code);
        $stmt->bindParam(":expertise_date", $this->expertise_date);
        $stmt->bindParam(":status", $this->status);
        $stmt->bindParam(":total_score", $this->total_score);
        $stmt->bindParam(":notes", $this->notes);
        $stmt->bindParam(":extra_data", $this->extra_data);
        $stmt->bindParam(":location", $this->location);
        $stmt->bindParam(":report_url", $this->report_url);

        // Sorguyu çalıştırma
        if ($stmt->execute()) {
            $this->id = $this->conn->lastInsertId();
            return true;
        }

        return false;
    }

    /**
     * Ekspertizi ID ile bulma
     *
     * @param int $id Ekspertiz ID
     * @return boolean İşlem başarılı mı
     */
    public function readOne($id) {
        // SQL sorgusu
        $query = "SELECT e.*, v.plate_number, v.vin_number, 
                  CONCAT(c.first_name, ' ', c.last_name) as customer_name,
                  CONCAT(u.full_name) as expert_name
                  FROM " . $this->table_name . " e
                  LEFT JOIN vehicles v ON e.vehicle_id = v.id
                  LEFT JOIN customers c ON e.customer_id = c.id
                  LEFT JOIN users u ON e.expert_id = u.id
                  WHERE e.id = :id
                  LIMIT 1";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // ID parametresini bağlama
        $stmt->bindParam(':id', $id);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Ekspertiz bulundu mu kontrol etme
        if ($stmt->rowCount() > 0) {
            // Ekspertiz verilerini alma
            return $stmt->fetch(PDO::FETCH_ASSOC);
        }

        return false;
    }

    /**
     * Ekspertiz extra_data alanını güncelleme
     *
     * @return boolean İşlem başarılı mı
     */
    public function updateExtraData() {
        // SQL sorgusu
        $query = "UPDATE " . $this->table_name . "
              SET extra_data = :extra_data, updated_at = NOW()
              WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(":id", $this->id);
        $stmt->bindParam(":extra_data", $this->extra_data);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Ekspertiz notlarını güncelleme
     *
     * @return boolean İşlem başarılı mı
     */
    public function updateNotes() {
        // SQL sorgusu
        $query = "UPDATE " . $this->table_name . "
              SET notes = :notes, updated_at = NOW()
              WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $this->notes = htmlspecialchars(strip_tags($this->notes));

        // Parametreleri bağlama
        $stmt->bindParam(":id", $this->id);
        $stmt->bindParam(":notes", $this->notes);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Ekspertiz bilgilerini güncelleme
     *
     * @return boolean İşlem başarılı mı
     */
    public function update() {
        // SQL sorgusu
        $query = "UPDATE " . $this->table_name . "
                  SET vehicle_id = :vehicle_id,
                      customer_id = :customer_id,
                      expert_id = :expert_id,
                      template_id = :template_id,
                      expertise_date = :expertise_date,
                      status = :status,
                      total_score = :total_score,
                      notes = :notes,
                      extra_data = :extra_data,
                      location = :location,
                      report_url = :report_url,
                      updated_at = NOW()
                  WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $this->status = htmlspecialchars(strip_tags($this->status));
        $this->notes = htmlspecialchars(strip_tags($this->notes));
        $this->location = htmlspecialchars(strip_tags($this->location));
        $this->report_url = htmlspecialchars(strip_tags($this->report_url));

        // Parametreleri bağlama
        $stmt->bindParam(":id", $this->id);
        $stmt->bindParam(":vehicle_id", $this->vehicle_id);
        $stmt->bindParam(":customer_id", $this->customer_id);
        $stmt->bindParam(":expert_id", $this->expert_id);
        $stmt->bindParam(":template_id", $this->template_id);
        $stmt->bindParam(":expertise_date", $this->expertise_date);
        $stmt->bindParam(":status", $this->status);
        $stmt->bindParam(":total_score", $this->total_score);
        $stmt->bindParam(":notes", $this->notes);
        $stmt->bindParam(":extra_data", $this->extra_data);
        $stmt->bindParam(":location", $this->location);
        $stmt->bindParam(":report_url", $this->report_url);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Ekspertiz silme
     *
     * @return boolean İşlem başarılı mı
     */
    public function delete() {
        // SQL sorgusu
        $query = "DELETE FROM " . $this->table_name . " WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // ID parametresini bağlama
        $stmt->bindParam(":id", $this->id);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Tüm ekspertizleri listeleme
     *
     * @param int $company_id Şirket ID
     * @param int $limit Limit
     * @param int $offset Offset
     * @param string $search Arama kelimesi
     * @param string $status Durum filtresi
     * @param string $sort_by Sıralama alanı
     * @param string $sort_dir Sıralama yönü
     * @return array Ekspertiz listesi
     */
    public function getExpertises($company_id, $limit = 10, $offset = 0, $search = null, $status = null, $sort_by = 'expertise_date', $sort_dir = 'DESC') {
        // SQL sorgusu
        $query = "SELECT e.id, e.expertise_code, e.expertise_date, e.status, e.total_score,
                  CONCAT(c.first_name, ' ', c.last_name) as customer_name,
                  CONCAT(v.plate_number, ' - ', b.brand_name, ' ', m.model_name) as vehicle_info,
                  u.full_name as expert_name
                  FROM " . $this->table_name . " e
                  LEFT JOIN vehicles v ON e.vehicle_id = v.id
                  LEFT JOIN car_brands b ON v.brand_id = b.id
                  LEFT JOIN car_models m ON v.model_id = m.id
                  LEFT JOIN customers c ON e.customer_id = c.id
                  LEFT JOIN users u ON e.expert_id = u.id
                  WHERE e.company_id = :company_id";

        $params = [":company_id" => $company_id];

        // Arama parametresi
        if ($search) {
            $query .= " AND (e.expertise_code LIKE :search 
                       OR c.first_name LIKE :search 
                       OR c.last_name LIKE :search
                       OR v.plate_number LIKE :search
                       OR CONCAT(c.first_name, ' ', c.last_name) LIKE :search)";
            $search = "%{$search}%";
            $params[":search"] = $search;
        }

        // Durum filtresi
        if ($status) {
            $query .= " AND e.status = :status";
            $params[":status"] = $status;
        }

        // Sıralama
        $query .= " ORDER BY e.{$sort_by} {$sort_dir}";

        // Limit ve offset
        $query .= " LIMIT :limit OFFSET :offset";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        foreach ($params as $key => $value) {
            $stmt->bindValue($key, $value);
        }

        $stmt->bindValue(":limit", (int)$limit, PDO::PARAM_INT);
        $stmt->bindValue(":offset", (int)$offset, PDO::PARAM_INT);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    /**
     * Toplam ekspertiz sayısını getirme
     *
     * @param int $company_id Şirket ID
     * @param string $search Arama kelimesi
     * @param string $status Durum filtresi
     * @return int Ekspertiz sayısı
     */
    public function countExpertises($company_id, $search = null, $status = null) {
        // SQL sorgusu
        $query = "SELECT COUNT(*) as total FROM " . $this->table_name . " e
                  LEFT JOIN vehicles v ON e.vehicle_id = v.id
                  LEFT JOIN customers c ON e.customer_id = c.id
                  WHERE e.company_id = :company_id";

        $params = [":company_id" => $company_id];

        // Arama parametresi
        if ($search) {
            $query .= " AND (e.expertise_code LIKE :search 
                       OR c.first_name LIKE :search 
                       OR c.last_name LIKE :search
                       OR v.plate_number LIKE :search
                       OR CONCAT(c.first_name, ' ', c.last_name) LIKE :search)";
            $search = "%{$search}%";
            $params[":search"] = $search;
        }

        // Durum filtresi
        if ($status) {
            $query .= " AND e.status = :status";
            $params[":status"] = $status;
        }

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        foreach ($params as $key => $value) {
            $stmt->bindValue($key, $value);
        }

        // Sorguyu çalıştırma
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);

        // Toplam sayıyı döndürme
        return (int)$row['total'];
    }

    /**
     * Son eklenen ekspertizleri getirme
     *
     * @param int $company_id Şirket ID
     * @param int $limit Limit
     * @return array Ekspertiz listesi
     */
    public function getRecentExpertises($company_id, $limit = 5) {
        // SQL sorgusu
        $query = "SELECT e.id, e.expertise_code, e.expertise_date, e.status,
                  CONCAT(c.first_name, ' ', c.last_name) as customer_name,
                  CONCAT(v.plate_number, ' - ', b.brand_name, ' ', m.model_name) as vehicle_info
                  FROM " . $this->table_name . " e
                  LEFT JOIN vehicles v ON e.vehicle_id = v.id
                  LEFT JOIN car_brands b ON v.brand_id = b.id
                  LEFT JOIN car_models m ON v.model_id = m.id
                  LEFT JOIN customers c ON e.customer_id = c.id
                  WHERE e.company_id = :company_id
                  ORDER BY e.created_at DESC
                  LIMIT :limit";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindValue(":company_id", $company_id);
        $stmt->bindValue(":limit", (int)$limit, PDO::PARAM_INT);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    /**
     * Aya göre ekspertiz sayısını getirme
     *
     * @param int $company_id Şirket ID
     * @param int $month Ay
     * @param int $year Yıl
     * @return int Ekspertiz sayısı
     */
    public function countExpertisesByMonth($company_id, $month, $year) {
        // SQL sorgusu
        $query = "SELECT COUNT(*) as total FROM " . $this->table_name . "
                  WHERE company_id = :company_id
                  AND MONTH(expertise_date) = :month
                  AND YEAR(expertise_date) = :year";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindValue(":company_id", $company_id);
        $stmt->bindValue(":month", $month);
        $stmt->bindValue(":year", $year);

        // Sorguyu çalıştırma
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);

        // Toplam sayıyı döndürme
        return (int)$row['total'];
    }

    /**
     * Duruma göre ekspertiz sayılarını getirme
     *
     * @param int $company_id Şirket ID
     * @return array Durum bazlı ekspertiz sayıları
     */
    public function getExpertiseCountsByStatus($company_id) {
        // SQL sorgusu
        $query = "SELECT status, COUNT(*) as count FROM " . $this->table_name . "
                  WHERE company_id = :company_id
                  GROUP BY status";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindValue(":company_id", $company_id);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        $results = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Durum bazlı dizi oluşturma
        $counts = [
            'pending' => 0,
            'in_progress' => 0,
            'completed' => 0,
            'cancelled' => 0
        ];

        foreach ($results as $row) {
            $counts[$row['status']] = (int)$row['count'];
        }

        return $counts;
    }
    /**
     * Ekspertiz kodu oluşturma
     *
     * @param int $company_id Şirket ID
     * @return string Benzersiz ekspertiz kodu
     */
    public function generateExpertiseCode($company_id) {
        // Tarih bazlı ön ek
        $prefix = 'EXP-' . date('Ym') . '-';

        // Son kullanılan kodun numarasını bulma
        $query = "SELECT expertise_code FROM " . $this->table_name . "
                  WHERE company_id = :company_id AND expertise_code LIKE :prefix
                  ORDER BY id DESC LIMIT 1";

        $stmt = $this->conn->prepare($query);
        $stmt->bindValue(":company_id", $company_id);
        $stmt->bindValue(":prefix", $prefix . '%');
        $stmt->execute();

        if ($stmt->rowCount() > 0) {
            $row = $stmt->fetch(PDO::FETCH_ASSOC);
            $lastCode = $row['expertise_code'];

            // Son kodun numara kısmını alma
            $lastNumber = intval(substr($lastCode, strlen($prefix)));

            // Yeni numara
            $newNumber = $lastNumber + 1;
        } else {
            // İlk kod ise numara 1'den başlat
            $newNumber = 1;
        }

        // Yeni kodu formatla (4 haneli numara)
        return $prefix . str_pad($newNumber, 4, '0', STR_PAD_LEFT);
    }

    /**
     * Aylık ekspertiz istatistiklerini getirme
     *
     * @param int $company_id Şirket ID
     * @param int $year Yıl
     * @return array Aylık ekspertiz sayıları
     */
    public function getMonthlyExpertiseStats($company_id, $year) {
        // SQL sorgusu
        $query = "SELECT MONTH(expertise_date) as month, COUNT(*) as count 
                  FROM " . $this->table_name . "
                  WHERE company_id = :company_id
                  AND YEAR(expertise_date) = :year
                  GROUP BY MONTH(expertise_date)
                  ORDER BY MONTH(expertise_date)";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindValue(":company_id", $company_id);
        $stmt->bindValue(":year", $year);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları düzenleme (tüm aylar için 0 başlangıç değeri)
        $stats = array_fill(1, 12, 0);

        // Veritabanından gelen değerleri doldurma
        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            $stats[(int)$row['month']] = (int)$row['count'];
        }

        return $stats;
    }

    /**
     * Ekspertiz sonuçlarını getirme
     *
     * @param int $expertise_id Ekspertiz ID
     * @return array Ekspertiz sonuçları
     */
    public function getExpertiseResults($expertise_id) {
        // SQL sorgusu
        $query = "SELECT er.*, ti.item_name, ti.item_type, tc.category_name
                  FROM expertise_results er
                  LEFT JOIN template_items ti ON er.item_id = ti.id
                  LEFT JOIN template_categories tc ON ti.category_id = tc.id
                  WHERE er.expertise_id = :expertise_id
                  ORDER BY tc.display_order, ti.display_order";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametre bağlama
        $stmt->bindParam(":expertise_id", $expertise_id);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    /**
     * Ekspertiz sonuçlarını kaydetme
     *
     * @param int $expertise_id Ekspertiz ID
     * @param array $results Sonuç verileri
     * @return boolean İşlem başarılı mı
     */
    public function saveExpertiseResults($expertise_id, $results) {
        try {
            // Transaction başlatma
            $this->conn->beginTransaction();

            // Önce mevcut sonuçları silme
            $deleteQuery = "DELETE FROM expertise_results WHERE expertise_id = :expertise_id";
            $deleteStmt = $this->conn->prepare($deleteQuery);
            $deleteStmt->bindParam(":expertise_id", $expertise_id);
            $deleteStmt->execute();

            // Yeni sonuçları ekleme
            $insertQuery = "INSERT INTO expertise_results (expertise_id, item_id, result_value, comment, photo_url, created_at)
                           VALUES (:expertise_id, :item_id, :result_value, :comment, :photo_url, NOW())";
            $insertStmt = $this->conn->prepare($insertQuery);

            foreach ($results as $result) {
                $insertStmt->bindParam(":expertise_id", $expertise_id);
                $insertStmt->bindParam(":item_id", $result['item_id']);
                $insertStmt->bindParam(":result_value", $result['result_value']);
                $insertStmt->bindParam(":comment", $result['comment']);
                $insertStmt->bindParam(":photo_url", $result['photo_url']);
                $insertStmt->execute();
            }

            // Transaction tamamlama
            $this->conn->commit();
            return true;

        } catch (Exception $e) {
            // Hata durumunda geri alma
            $this->conn->rollBack();
            error_log("Ekspertiz sonuçları kaydetme hatası: " . $e->getMessage());
            return false;
        }
    }
    /**
     * Ekspertiz fotoğraflarını getirme
     *
     * @param int $expertise_id Ekspertiz ID
     * @return array Ekspertiz fotoğrafları
     */
    public function getExpertisePhotos($expertise_id) {
        // SQL sorgusu
        $query = "SELECT id, photo_url, photo_type, photo_description, created_at
                  FROM vehicle_photos
                  WHERE expertise_id = :expertise_id
                  ORDER BY created_at DESC";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametre bağlama
        $stmt->bindParam(":expertise_id", $expertise_id);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    /**
     * Ekspertiz fotoğrafı ekleme
     *
     * @param int $expertise_id Ekspertiz ID
     * @param string $photo_url Fotoğraf URL
     * @param string $photo_type Fotoğraf tipi
     * @param string $photo_description Fotoğraf açıklaması
     * @return boolean İşlem başarılı mı
     */
    public function addExpertisePhoto($expertise_id, $photo_url, $photo_type = 'other', $photo_description = '') {
        // SQL sorgusu
        $query = "INSERT INTO vehicle_photos (expertise_id, photo_url, photo_type, photo_description, created_at)
                  VALUES (:expertise_id, :photo_url, :photo_type, :photo_description, NOW())";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $photo_url = htmlspecialchars(strip_tags($photo_url));
        $photo_type = htmlspecialchars(strip_tags($photo_type));
        $photo_description = htmlspecialchars(strip_tags($photo_description));

        // Parametreleri bağlama
        $stmt->bindParam(":expertise_id", $expertise_id);
        $stmt->bindParam(":photo_url", $photo_url);
        $stmt->bindParam(":photo_type", $photo_type);
        $stmt->bindParam(":photo_description", $photo_description);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Ekspertiz fotoğrafı silme
     *
     * @param int $photo_id Fotoğraf ID
     * @return boolean İşlem başarılı mı
     */
    public function deleteExpertisePhoto($photo_id) {
        // SQL sorgusu
        $query = "DELETE FROM vehicle_photos WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametre bağlama
        $stmt->bindParam(":id", $photo_id);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Toplam puan hesaplama
     *
     * @param int $expertise_id Ekspertiz ID
     * @return float Toplam puan
     */
    public function calculateTotalScore($expertise_id) {
        // SQL sorgusu (sadece puanlama öğeleri için)
        $query = "SELECT AVG(CAST(er.result_value AS DECIMAL(5,2))) as avg_score
                  FROM expertise_results er
                  LEFT JOIN template_items ti ON er.item_id = ti.id
                  WHERE er.expertise_id = :expertise_id
                  AND ti.item_type = 'score'";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametre bağlama
        $stmt->bindParam(":expertise_id", $expertise_id);

        // Sorguyu çalıştırma
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);

        // Ortalama puanı döndürme
        return ($row['avg_score']) ? round(floatval($row['avg_score']), 2) : 0;
    }

    /**
     * Ekspertiz durumunu güncelleme
     *
     * @param int $id Ekspertiz ID
     * @param string $status Yeni durum
     * @return boolean İşlem başarılı mı
     */
    public function updateStatus($id, $status) {
        // SQL sorgusu
        $query = "UPDATE " . $this->table_name . "
                  SET status = :status, updated_at = NOW()
                  WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $status = htmlspecialchars(strip_tags($status));

        // Parametreleri bağlama
        $stmt->bindParam(":id", $id);
        $stmt->bindParam(":status", $status);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Ekspertiz raporunu oluşturma/güncelleme
     *
     * @param int $id Ekspertiz ID
     * @param string $report_url Rapor URL
     * @return boolean İşlem başarılı mı
     */
    public function updateReportUrl($id, $report_url) {
        // SQL sorgusu
        $query = "UPDATE " . $this->table_name . "
                  SET report_url = :report_url, updated_at = NOW()
                  WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $report_url = htmlspecialchars(strip_tags($report_url));

        // Parametreleri bağlama
        $stmt->bindParam(":id", $id);
        $stmt->bindParam(":report_url", $report_url);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Araç için ekspertiz geçmişini getirme
     *
     * @param int $vehicle_id Araç ID
     * @return array Ekspertiz geçmişi
     */
    public function getExpertiseHistoryByVehicle($vehicle_id) {
        // SQL sorgusu
        $query = "SELECT e.id, e.expertise_code, e.expertise_date, e.status, e.total_score,
                  u.full_name as expert_name
                  FROM " . $this->table_name . " e
                  LEFT JOIN users u ON e.expert_id = u.id
                  WHERE e.vehicle_id = :vehicle_id
                  ORDER BY e.expertise_date DESC";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametre bağlama
        $stmt->bindParam(":vehicle_id", $vehicle_id);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
}