<?php
/**
 * Kaporta Testi işlemleri sınıfı
 */
class KaportaTest {
    // Veritabanı bağlantısı ve tablo
    private $conn;
    private $table_name = "kaporta_test";

    // Kaporta Testi özellikleri
    public $id;
    public $expertise_id;
    public $vehicle_id;
    public $drawing_data;
    public $notes;
    public $created_at;
    public $updated_at;

    /**
     * Sınıf başlatıcı
     *
     * @param PDO $db Veritabanı bağlantısı
     */
    public function __construct($db) {
        $this->conn = $db;
    }

    /**
     * Yeni kaporta testi kaydı oluşturma
     *
     * @return boolean İşlem başarılı mı
     */
    public function create() {
        // SQL sorgusu
        $query = "INSERT INTO " . $this->table_name . "
                  (expertise_id, vehicle_id, drawing_data, notes, created_at)
                  VALUES
                  (:expertise_id, :vehicle_id, :drawing_data, :notes, NOW())";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $this->notes = htmlspecialchars(strip_tags($this->notes));

        // Parametreleri bağlama
        $stmt->bindParam(":expertise_id", $this->expertise_id);
        $stmt->bindParam(":vehicle_id", $this->vehicle_id);
        $stmt->bindParam(":drawing_data", $this->drawing_data);
        $stmt->bindParam(":notes", $this->notes);

        // Sorguyu çalıştırma
        if ($stmt->execute()) {
            $this->id = $this->conn->lastInsertId();
            return true;
        }

        return false;
    }

    /**
     * Kaporta testini güncelleme
     *
     * @return boolean İşlem başarılı mı
     */
    public function update() {
        // SQL sorgusu
        $query = "UPDATE " . $this->table_name . "
                  SET drawing_data = :drawing_data,
                      notes = :notes,
                      updated_at = NOW()
                  WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $this->notes = htmlspecialchars(strip_tags($this->notes));

        // Parametreleri bağlama
        $stmt->bindParam(":id", $this->id);
        $stmt->bindParam(":drawing_data", $this->drawing_data);
        $stmt->bindParam(":notes", $this->notes);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Ekspertiz ID'sine göre kaporta testi getirme
     *
     * @param int $expertise_id Ekspertiz ID
     * @return array|boolean Test verileri veya başarısız ise false
     */
    public function readByExpertiseId($expertise_id) {
        // SQL sorgusu
        $query = "SELECT * FROM " . $this->table_name . " 
                  WHERE expertise_id = :expertise_id 
                  LIMIT 1";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(':expertise_id', $expertise_id);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Kaporta testi bulundu mu kontrol etme
        if ($stmt->rowCount() > 0) {
            return $stmt->fetch(PDO::FETCH_ASSOC);
        }

        return false;
    }

    /**
     * Kaporta testini ekspertiz ID'sine göre kaydetme veya güncelleme
     *
     * @return boolean İşlem başarılı mı
     */
    public function saveOrUpdate() {
        // Önce kayıt mevcut mu kontrol et
        $query = "SELECT id FROM " . $this->table_name . " 
                  WHERE expertise_id = :expertise_id 
                  LIMIT 1";

        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(':expertise_id', $this->expertise_id);
        $stmt->execute();

        if ($stmt->rowCount() > 0) {
            // Kayıt varsa güncelle
            $row = $stmt->fetch(PDO::FETCH_ASSOC);
            $this->id = $row['id'];
            return $this->update();
        } else {
            // Kayıt yoksa oluştur
            return $this->create();
        }
    }
}
?>