<?php
/**
 * Ekspertiz şablonu işlemleri sınıfı
 */
class Template {
    // Veritabanı bağlantısı ve tablo
    private $conn;
    private $table_name = "expertise_templates";

    // Şablon özellikleri
    public $id;
    public $company_id;
    public $template_name;
    public $description;
    public $status;
    public $created_at;
    public $updated_at;

    /**
     * Sınıf başlatıcı
     *
     * @param PDO $db Veritabanı bağlantısı
     */
    public function __construct($db) {
        $this->conn = $db;
    }

    /**
     * Yeni şablon oluşturma
     *
     * @return boolean İşlem başarılı mı
     */
    public function create() {
        // SQL sorgusu
        $query = "INSERT INTO " . $this->table_name . "
                  (company_id, template_name, description, status, created_at)
                  VALUES
                  (:company_id, :template_name, :description, :status, NOW())";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $this->template_name = htmlspecialchars(strip_tags($this->template_name));
        $this->description = htmlspecialchars(strip_tags($this->description));
        $this->status = htmlspecialchars(strip_tags($this->status));

        // Parametreleri bağlama
        $stmt->bindParam(":company_id", $this->company_id);
        $stmt->bindParam(":template_name", $this->template_name);
        $stmt->bindParam(":description", $this->description);
        $stmt->bindParam(":status", $this->status);

        // Sorguyu çalıştırma
        if ($stmt->execute()) {
            $this->id = $this->conn->lastInsertId();
            return true;
        }

        return false;
    }

    /**
     * Şablonu ID ile bulma
     *
     * @param int $id Şablon ID
     * @return boolean İşlem başarılı mı
     */
    public function readOne($id) {
        // SQL sorgusu
        $query = "SELECT * FROM " . $this->table_name . " WHERE id = :id LIMIT 1";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // ID parametresini bağlama
        $stmt->bindParam(':id', $id);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Şablon bulundu mu kontrol etme
        if ($stmt->rowCount() > 0) {
            // Şablon verilerini alma
            $row = $stmt->fetch(PDO::FETCH_ASSOC);

            // Şablon özelliklerini ayarlama
            $this->id = $row['id'];
            $this->company_id = $row['company_id'];
            $this->template_name = $row['template_name'];
            $this->description = $row['description'];
            $this->status = $row['status'];
            $this->created_at = $row['created_at'];
            $this->updated_at = $row['updated_at'];

            return true;
        }

        return false;
    }
    /**
     * Şablon bilgilerini güncelleme
     *
     * @return boolean İşlem başarılı mı
     */
    public function update() {
        // SQL sorgusu
        $query = "UPDATE " . $this->table_name . "
                  SET template_name = :template_name,
                      description = :description,
                      status = :status,
                      updated_at = NOW()
                  WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $this->template_name = htmlspecialchars(strip_tags($this->template_name));
        $this->description = htmlspecialchars(strip_tags($this->description));
        $this->status = htmlspecialchars(strip_tags($this->status));

        // Parametreleri bağlama
        $stmt->bindParam(":id", $this->id);
        $stmt->bindParam(":template_name", $this->template_name);
        $stmt->bindParam(":description", $this->description);
        $stmt->bindParam(":status", $this->status);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Şablon silme
     *
     * @return boolean İşlem başarılı mı
     */
    public function delete() {
        // SQL sorgusu
        $query = "DELETE FROM " . $this->table_name . " WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // ID parametresini bağlama
        $stmt->bindParam(":id", $this->id);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Tüm şablonları listeleme
     *
     * @param int $company_id Şirket ID
     * @param string $status Durum filtresi (opsiyonel)
     * @return array Şablon listesi
     */
    public function getTemplates($company_id, $status = null) {
        // SQL sorgusu
        $query = "SELECT id, template_name, description, status, created_at
                  FROM " . $this->table_name . "
                  WHERE company_id = :company_id";

        // Durum filtresi varsa ekle
        if ($status) {
            $query .= " AND status = :status";
        }

        // Sıralama
        $query .= " ORDER BY template_name ASC";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(":company_id", $company_id);

        if ($status) {
            $stmt->bindParam(":status", $status);
        }

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
    /**
     * Şablonun kategorilerini getirme
     *
     * @param int $template_id Şablon ID
     * @return array Kategori listesi
     */
    public function getTemplateCategories($template_id) {
        // SQL sorgusu
        $query = "SELECT id, category_name, display_order
                  FROM template_categories
                  WHERE template_id = :template_id
                  ORDER BY display_order ASC";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(":template_id", $template_id);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    /**
     * Kategorinin öğelerini getirme
     *
     * @param int $category_id Kategori ID
     * @return array Öğe listesi
     */
    public function getCategoryItems($category_id) {
        // SQL sorgusu
        $query = "SELECT id, item_name, item_type, display_order
                  FROM template_items
                  WHERE category_id = :category_id
                  ORDER BY display_order ASC";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(":category_id", $category_id);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    /**
     * Şablonun tüm öğelerini hiyerarşik olarak getirme
     *
     * @param int $template_id Şablon ID
     * @return array Hiyerarşik öğe listesi
     */
    public function getTemplateStructure($template_id) {
        // Şablonu oku
        $this->readOne($template_id);

        // Sonuç dizisi
        $result = [
            'template_id' => $this->id,
            'template_name' => $this->template_name,
            'description' => $this->description,
            'categories' => []
        ];

        // Kategorileri getir
        $categories = $this->getTemplateCategories($template_id);

        // Her kategori için öğeleri getir
        foreach ($categories as $category) {
            $items = $this->getCategoryItems($category['id']);

            // Kategori ve öğelerini sonuç dizisine ekle
            $result['categories'][] = [
                'category_id' => $category['id'],
                'category_name' => $category['category_name'],
                'display_order' => $category['display_order'],
                'items' => $items
            ];
        }

        return $result;
    }
    /**
     * Yeni kategori ekleme
     *
     * @param int $template_id Şablon ID
     * @param string $category_name Kategori adı
     * @param int $display_order Görüntüleme sırası
     * @return int|bool Eklenen kategori ID'si veya false
     */
    public function addCategory($template_id, $category_name, $display_order = 0) {
        // SQL sorgusu
        $query = "INSERT INTO template_categories (template_id, category_name, display_order, created_at)
                  VALUES (:template_id, :category_name, :display_order, NOW())";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $category_name = htmlspecialchars(strip_tags($category_name));

        // Parametreleri bağlama
        $stmt->bindParam(":template_id", $template_id);
        $stmt->bindParam(":category_name", $category_name);
        $stmt->bindParam(":display_order", $display_order);

        // Sorguyu çalıştırma
        if ($stmt->execute()) {
            return $this->conn->lastInsertId();
        }

        return false;
    }

    /**
     * Kategori güncelleme
     *
     * @param int $category_id Kategori ID
     * @param string $category_name Kategori adı
     * @param int $display_order Görüntüleme sırası
     * @return boolean İşlem başarılı mı
     */
    public function updateCategory($category_id, $category_name, $display_order) {
        // SQL sorgusu
        $query = "UPDATE template_categories 
                  SET category_name = :category_name,
                      display_order = :display_order,
                      updated_at = NOW()
                  WHERE id = :category_id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $category_name = htmlspecialchars(strip_tags($category_name));

        // Parametreleri bağlama
        $stmt->bindParam(":category_id", $category_id);
        $stmt->bindParam(":category_name", $category_name);
        $stmt->bindParam(":display_order", $display_order);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Kategori silme
     *
     * @param int $category_id Kategori ID
     * @return boolean İşlem başarılı mı
     */
    public function deleteCategory($category_id) {
        // SQL sorgusu
        $query = "DELETE FROM template_categories WHERE id = :category_id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(":category_id", $category_id);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Yeni öğe ekleme
     *
     * @param int $category_id Kategori ID
     * @param string $item_name Öğe adı
     * @param string $item_type Öğe tipi (check, score, color, text, photo)
     * @param int $display_order Görüntüleme sırası
     * @return int|bool Eklenen öğe ID'si veya false
     */
    public function addItem($category_id, $item_name, $item_type, $display_order = 0) {
        // SQL sorgusu
        $query = "INSERT INTO template_items (category_id, item_name, item_type, display_order, created_at)
                  VALUES (:category_id, :item_name, :item_type, :display_order, NOW())";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $item_name = htmlspecialchars(strip_tags($item_name));
        $item_type = htmlspecialchars(strip_tags($item_type));

        // Parametreleri bağlama
        $stmt->bindParam(":category_id", $category_id);
        $stmt->bindParam(":item_name", $item_name);
        $stmt->bindParam(":item_type", $item_type);
        $stmt->bindParam(":display_order", $display_order);

        // Sorguyu çalıştırma
        if ($stmt->execute()) {
            return $this->conn->lastInsertId();
        }

        return false;
    }
    /**
     * Öğe güncelleme
     *
     * @param int $item_id Öğe ID
     * @param string $item_name Öğe adı
     * @param string $item_type Öğe tipi
     * @param int $display_order Görüntüleme sırası
     * @return boolean İşlem başarılı mı
     */
    public function updateItem($item_id, $item_name, $item_type, $display_order) {
        // SQL sorgusu
        $query = "UPDATE template_items 
                  SET item_name = :item_name,
                      item_type = :item_type,
                      display_order = :display_order,
                      updated_at = NOW()
                  WHERE id = :item_id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $item_name = htmlspecialchars(strip_tags($item_name));
        $item_type = htmlspecialchars(strip_tags($item_type));

        // Parametreleri bağlama
        $stmt->bindParam(":item_id", $item_id);
        $stmt->bindParam(":item_name", $item_name);
        $stmt->bindParam(":item_type", $item_type);
        $stmt->bindParam(":display_order", $display_order);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Öğe silme
     *
     * @param int $item_id Öğe ID
     * @return boolean İşlem başarılı mı
     */
    public function deleteItem($item_id) {
        // SQL sorgusu
        $query = "DELETE FROM template_items WHERE id = :item_id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(":item_id", $item_id);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Şablonu kopyalama
     *
     * @param int $template_id Kaynak şablon ID
     * @param string $new_name Yeni şablon adı
     * @return int|bool Yeni şablon ID'si veya false
     */
    public function cloneTemplate($template_id, $new_name) {
        try {
            // Transaction başlat
            $this->conn->beginTransaction();

            // Kaynak şablonu oku
            $this->readOne($template_id);

            // Yeni şablon özelliklerini ayarla
            $this->template_name = $new_name;
            $this->description = "Kopyalanan şablon: " . $this->description;

            // Yeni şablonu oluştur
            if (!$this->create()) {
                throw new Exception("Şablon kopyalanamadı.");
            }

            $new_template_id = $this->id;

            // Kategorileri getir
            $categories = $this->getTemplateCategories($template_id);

            // Kategori eşleştirme dizisi (eski ID => yeni ID)
            $category_map = [];

            // Kategorileri kopyala
            foreach ($categories as $category) {
                $new_category_id = $this->addCategory(
                    $new_template_id,
                    $category['category_name'],
                    $category['display_order']
                );

                if (!$new_category_id) {
                    throw new Exception("Kategori kopyalanamadı.");
                }

                // Kategori eşleştirmesini kaydet
                $category_map[$category['id']] = $new_category_id;

                // Öğeleri getir
                $items = $this->getCategoryItems($category['id']);

                // Öğeleri kopyala
                foreach ($items as $item) {
                    $new_item_id = $this->addItem(
                        $new_category_id,
                        $item['item_name'],
                        $item['item_type'],
                        $item['display_order']
                    );

                    if (!$new_item_id) {
                        throw new Exception("Öğe kopyalanamadı.");
                    }
                }
            }

            // Transaction başarıyla tamamla
            $this->conn->commit();

            return $new_template_id;

        } catch (Exception $e) {
            // Hata durumunda rollback
            $this->conn->rollBack();

            // Hata mesajını logla
            error_log("Şablon kopyalama hatası: " . $e->getMessage());

            return false;
        }
    }

    /**
     * Şablon istatistiklerini getirme
     *
     * @param int $template_id Şablon ID
     * @return array İstatistikler
     */
    public function getTemplateStats($template_id) {
        // Kategorileri say
        $query1 = "SELECT COUNT(*) as category_count 
                  FROM template_categories 
                  WHERE template_id = :template_id";

        $stmt1 = $this->conn->prepare($query1);
        $stmt1->bindParam(":template_id", $template_id);
        $stmt1->execute();
        $category_count = $stmt1->fetch(PDO::FETCH_ASSOC)['category_count'];

        // Öğeleri say ve türlerine göre grupla
        $query2 = "SELECT ti.item_type, COUNT(*) as count
                  FROM template_items ti
                  JOIN template_categories tc ON ti.category_id = tc.id
                  WHERE tc.template_id = :template_id
                  GROUP BY ti.item_type";

        $stmt2 = $this->conn->prepare($query2);
        $stmt2->bindParam(":template_id", $template_id);
        $stmt2->execute();

        $item_stats = [];
        while ($row = $stmt2->fetch(PDO::FETCH_ASSOC)) {
            $item_stats[$row['item_type']] = $row['count'];
        }

        // Toplam öğe sayısı
        $query3 = "SELECT COUNT(*) as item_count
                  FROM template_items ti
                  JOIN template_categories tc ON ti.category_id = tc.id
                  WHERE tc.template_id = :template_id";

        $stmt3 = $this->conn->prepare($query3);
        $stmt3->bindParam(":template_id", $template_id);
        $stmt3->execute();
        $item_count = $stmt3->fetch(PDO::FETCH_ASSOC)['item_count'];

        // Sonuçları döndür
        return [
            'category_count' => $category_count,
            'item_count' => $item_count,
            'items_by_type' => $item_stats
        ];
    }
}