<?php
/**
 * Kullanıcı işlemleri sınıfı
 */
class User {
    // Veritabanı bağlantısı ve tablo
    private $conn;
    private $table_name = "users";

    // Kullanıcı özellikleri
    public $id;
    public $username;
    public $password;
    public $email;
    public $full_name;
    public $role;
    public $company_id;
    public $status;
    public $created_at;
    public $updated_at;

    /**
     * Sınıf başlatıcı
     *
     * @param PDO $db Veritabanı bağlantısı
     */
    public function __construct($db) {
        $this->conn = $db;
    }

    /**
     * Kullanıcı giriş işlemi
     *
     * @param string $username Kullanıcı adı
     * @param string $password Şifre
     * @return array|false Kullanıcı verileri veya false
     */
    public function login($username, $password) {
        // SQL sorgusu
        $query = "SELECT id, username, password, email, full_name, role, company_id, status, created_at, updated_at
                  FROM " . $this->table_name . "
                  WHERE username = :username OR email = :email
                  LIMIT 1";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(":username", $username);
        $stmt->bindParam(":email", $username); // E-posta ile de giriş yapılabilir

        // Sorguyu çalıştırma
        $stmt->execute();

        // Kullanıcı bulundu mu kontrol etme
        if ($stmt->rowCount() > 0) {
            // Kullanıcı verilerini alma
            $user = $stmt->fetch(PDO::FETCH_ASSOC);

            // Şifre doğrulama
            if (password_verify($password, $user['password'])) {
                // Şifre doğru, kullanıcı verilerini döndürme
                return $user;
            }
        }

        // Kullanıcı bulunamadı veya şifre yanlış
        return false;
    }

    /**
     * Yeni kullanıcı oluşturma
     *
     * @return boolean İşlem başarılı mı
     */
    public function create() {
        // SQL sorgusu
        $query = "INSERT INTO " . $this->table_name . "
                  (username, password, email, full_name, role, company_id, status, created_at)
                  VALUES
                  (:username, :password, :email, :full_name, :role, :company_id, :status, NOW())";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $this->username = htmlspecialchars(strip_tags($this->username));
        $this->email = htmlspecialchars(strip_tags($this->email));
        $this->full_name = htmlspecialchars(strip_tags($this->full_name));
        $this->role = htmlspecialchars(strip_tags($this->role));
        $this->status = htmlspecialchars(strip_tags($this->status));

        // Şifreyi hash'leme
        $password_hash = password_hash($this->password, PASSWORD_BCRYPT);

        // Parametreleri bağlama
        $stmt->bindParam(":username", $this->username);
        $stmt->bindParam(":password", $password_hash);
        $stmt->bindParam(":email", $this->email);
        $stmt->bindParam(":full_name", $this->full_name);
        $stmt->bindParam(":role", $this->role);
        $stmt->bindParam(":company_id", $this->company_id);
        $stmt->bindParam(":status", $this->status);

        // Sorguyu çalıştırma
        if ($stmt->execute()) {
            $this->id = $this->conn->lastInsertId();
            return true;
        }

        return false;
    }

    /**
     * Kullanıcıyı ID ile bulma
     *
     * @param int $id Kullanıcı ID
     * @return boolean İşlem başarılı mı
     */
    public function readOne($id) {
        // SQL sorgusu
        $query = "SELECT id, username, email, full_name, role, company_id, status, created_at, updated_at
                  FROM " . $this->table_name . "
                  WHERE id = :id
                  LIMIT 1";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // ID parametresini bağlama
        $stmt->bindParam(':id', $id);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Kullanıcı bulundu mu kontrol etme
        if ($stmt->rowCount() > 0) {
            // Kullanıcı verilerini alma
            $row = $stmt->fetch(PDO::FETCH_ASSOC);

            // Kullanıcı özelliklerini ayarlama
            $this->id = $row['id'];
            $this->username = $row['username'];
            $this->email = $row['email'];
            $this->full_name = $row['full_name'];
            $this->role = $row['role'];
            $this->company_id = $row['company_id'];
            $this->status = $row['status'];
            $this->created_at = $row['created_at'];
            $this->updated_at = $row['updated_at'];

            return true;
        }

        return false;
    }

    /**
     * Kullanıcı bilgilerini güncelleme
     *
     * @return boolean İşlem başarılı mı
     */
    public function update() {
        // SQL sorgusu (şifre güncellenmiyorsa)
        $query = "UPDATE " . $this->table_name . "
                  SET email = :email,
                      full_name = :full_name,
                      role = :role,
                      company_id = :company_id,
                      status = :status,
                      updated_at = NOW()
                  WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $this->email = htmlspecialchars(strip_tags($this->email));
        $this->full_name = htmlspecialchars(strip_tags($this->full_name));
        $this->role = htmlspecialchars(strip_tags($this->role));
        $this->status = htmlspecialchars(strip_tags($this->status));

        // Parametreleri bağlama
        $stmt->bindParam(":id", $this->id);
        $stmt->bindParam(":email", $this->email);
        $stmt->bindParam(":full_name", $this->full_name);
        $stmt->bindParam(":role", $this->role);
        $stmt->bindParam(":company_id", $this->company_id);
        $stmt->bindParam(":status", $this->status);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Kullanıcı şifresini güncelleme
     *
     * @param string $new_password Yeni şifre
     * @return boolean İşlem başarılı mı
     */
    public function updatePassword($new_password) {
        // SQL sorgusu
        $query = "UPDATE " . $this->table_name . "
                  SET password = :password,
                      updated_at = NOW()
                  WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Şifreyi hash'leme
        $password_hash = password_hash($new_password, PASSWORD_BCRYPT);

        // Parametreleri bağlama
        $stmt->bindParam(":id", $this->id);
        $stmt->bindParam(":password", $password_hash);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Kullanıcı silme
     *
     * @return boolean İşlem başarılı mı
     */
    public function delete() {
        // SQL sorgusu
        $query = "DELETE FROM " . $this->table_name . " WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // ID parametresini bağlama
        $stmt->bindParam(":id", $this->id);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Kullanıcı adının mevcut olup olmadığını kontrol etme
     *
     * @param string $username Kullanıcı adı
     * @return boolean Kullanıcı adı mevcut mu
     */
    public function isUsernameExists($username) {
        // SQL sorgusu
        $query = "SELECT id FROM " . $this->table_name . " WHERE username = :username LIMIT 1";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Kullanıcı adı parametresini bağlama
        $stmt->bindParam(":username", $username);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonucu kontrol etme
        return $stmt->rowCount() > 0;
    }

    /**
     * E-posta adresinin mevcut olup olmadığını kontrol etme
     *
     * @param string $email E-posta adresi
     * @return boolean E-posta adresi mevcut mu
     */
    public function isEmailExists($email) {
        // SQL sorgusu
        $query = "SELECT id FROM " . $this->table_name . " WHERE email = :email LIMIT 1";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // E-posta parametresini bağlama
        $stmt->bindParam(":email", $email);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonucu kontrol etme
        return $stmt->rowCount() > 0;
    }

    /**
     * Beni hatırla için token kaydetme
     *
     * @param int $user_id Kullanıcı ID
     * @param string $token Token
     * @param int $expiry Son geçerlilik tarihi
     * @return boolean İşlem başarılı mı
     */
    public function saveRememberToken($user_id, $token, $expiry) {
        // Eski tokenları temizleme
        $cleanQuery = "DELETE FROM user_tokens WHERE user_id = :user_id AND type = 'remember'";
        $cleanStmt = $this->conn->prepare($cleanQuery);
        $cleanStmt->bindParam(":user_id", $user_id);
        $cleanStmt->execute();

        // Yeni token ekleme
        $query = "INSERT INTO user_tokens (user_id, token, type, expires_at, created_at)
                  VALUES (:user_id, :token, 'remember', FROM_UNIXTIME(:expiry), NOW())";

        $stmt = $this->conn->prepare($query);

        $stmt->bindParam(":user_id", $user_id);
        $stmt->bindParam(":token", $token);
        $stmt->bindParam(":expiry", $expiry);

        return $stmt->execute();
    }

    /**
     * Token ile kullanıcı bilgilerini getirme
     *
     * @param string $token Token
     * @param string $type Token türü (remember, reset, vb.)
     * @return array|false Kullanıcı verileri veya false
     */
    public function getUserByToken($token, $type = 'remember') {
        $query = "SELECT u.id, u.username, u.email, u.full_name, u.role, u.company_id, u.status
                  FROM " . $this->table_name . " u
                  JOIN user_tokens t ON u.id = t.user_id
                  WHERE t.token = :token 
                  AND t.type = :type 
                  AND t.expires_at > NOW()
                  LIMIT 1";

        $stmt = $this->conn->prepare($query);

        $stmt->bindParam(":token", $token);
        $stmt->bindParam(":type", $type);

        $stmt->execute();

        if ($stmt->rowCount() > 0) {
            return $stmt->fetch(PDO::FETCH_ASSOC);
        }

        return false;
    }

    /**
     * Kullanıcı aktivitesini kaydetme
     *
     * @param int $user_id Kullanıcı ID
     * @param string $action İşlem türü
     * @param string $description Açıklama
     * @return boolean İşlem başarılı mı
     */
    public function logActivity($user_id, $action, $description) {
        $query = "INSERT INTO user_activities (user_id, action, description, ip_address, created_at)
                  VALUES (:user_id, :action, :description, :ip, NOW())";

        $stmt = $this->conn->prepare($query);

        // IP adresini alma
        $ip = $_SERVER['REMOTE_ADDR'] ?? '0.0.0.0';

        $stmt->bindParam(":user_id", $user_id);
        $stmt->bindParam(":action", $action);
        $stmt->bindParam(":description", $description);
        $stmt->bindParam(":ip", $ip);

        return $stmt->execute();
    }

    /**
     * Şirkete göre kullanıcıları listeleme (SaaS yapısı için)
     *
     * @param int $company_id Şirket ID
     * @param string $role Rol filtresi (opsiyonel)
     * @return array Kullanıcı listesi
     */
    public function getUsersByCompany($company_id, $role = null) {
        $query = "SELECT id, username, email, full_name, role, status, created_at
                  FROM " . $this->table_name . "
                  WHERE company_id = :company_id";

        if ($role) {
            $query .= " AND role = :role";
        }

        $query .= " ORDER BY full_name ASC";

        $stmt = $this->conn->prepare($query);

        $stmt->bindParam(":company_id", $company_id);

        if ($role) {
            $stmt->bindParam(":role", $role);
        }

        $stmt->execute();

        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    /**
     * Şifre sıfırlama tokeni oluşturma
     *
     * @param string $email Kullanıcı e-posta adresi
     * @return string|false Oluşturulan token veya false
     */
    public function createPasswordResetToken($email) {
        // Kullanıcıyı e-posta ile bulma
        $query = "SELECT id FROM " . $this->table_name . " WHERE email = :email AND status = 'active' LIMIT 1";
        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(":email", $email);
        $stmt->execute();

        if ($stmt->rowCount() > 0) {
            $row = $stmt->fetch(PDO::FETCH_ASSOC);
            $user_id = $row['id'];

            // Eski tokenları temizleme
            $cleanQuery = "DELETE FROM user_tokens WHERE user_id = :user_id AND type = 'reset'";
            $cleanStmt = $this->conn->prepare($cleanQuery);
            $cleanStmt->bindParam(":user_id", $user_id);
            $cleanStmt->execute();

            // Yeni token oluşturma ve kaydetme
            $token = bin2hex(random_bytes(32));
            $expiry = time() + (24 * 60 * 60); // 24 saat

            $tokenQuery = "INSERT INTO user_tokens (user_id, token, type, expires_at, created_at)
                           VALUES (:user_id, :token, 'reset', FROM_UNIXTIME(:expiry), NOW())";

            $tokenStmt = $this->conn->prepare($tokenQuery);
            $tokenStmt->bindParam(":user_id", $user_id);
            $tokenStmt->bindParam(":token", $token);
            $tokenStmt->bindParam(":expiry", $expiry);

            if ($tokenStmt->execute()) {
                return $token;
            }
        }

        return false;
    }

    /**
     * Şifre sıfırlama tokeni ile şifre yenileme
     *
     * @param string $token Şifre sıfırlama tokeni
     * @param string $new_password Yeni şifre
     * @return boolean İşlem başarılı mı
     */
    public function resetPasswordWithToken($token, $new_password) {
        // Token ile kullanıcıyı bulma
        $query = "SELECT u.id 
                  FROM " . $this->table_name . " u
                  JOIN user_tokens t ON u.id = t.user_id
                  WHERE t.token = :token 
                  AND t.type = 'reset' 
                  AND t.expires_at > NOW()
                  LIMIT 1";

        $stmt = $this->conn->prepare($query);
        $stmt->bindParam(":token", $token);
        $stmt->execute();

        if ($stmt->rowCount() > 0) {
            $row = $stmt->fetch(PDO::FETCH_ASSOC);
            $user_id = $row['id'];

            // Şifreyi hash'leme
            $password_hash = password_hash($new_password, PASSWORD_BCRYPT);

            // Şifreyi güncelleme
            $updateQuery = "UPDATE " . $this->table_name . "
                           SET password = :password,
                               updated_at = NOW()
                           WHERE id = :id";

            $updateStmt = $this->conn->prepare($updateQuery);
            $updateStmt->bindParam(":id", $user_id);
            $updateStmt->bindParam(":password", $password_hash);

            if ($updateStmt->execute()) {
                // Token'ı silme
                $deleteQuery = "DELETE FROM user_tokens WHERE token = :token AND type = 'reset'";
                $deleteStmt = $this->conn->prepare($deleteQuery);
                $deleteStmt->bindParam(":token", $token);
                $deleteStmt->execute();

                return true;
            }
        }

        return false;
    }

    /**
     * Kullanıcıların tümünü listeleme (admin için)
     *
     * @param int $limit Limit
     * @param int $offset Offset
     * @param string $search Arama kelimesi
     * @return array Kullanıcı listesi
     */
    public function getUsers($limit = 10, $offset = 0, $search = null) {
        $query = "SELECT id, username, email, full_name, role, company_id, status, created_at
                  FROM " . $this->table_name;

        $params = [];

        if ($search) {
            $query .= " WHERE (username LIKE :search OR email LIKE :search OR full_name LIKE :search)";
            $search = "%{$search}%";
            $params[":search"] = $search;
        }

        $query .= " ORDER BY id DESC LIMIT :limit OFFSET :offset";

        $stmt = $this->conn->prepare($query);

        foreach ($params as $key => $value) {
            $stmt->bindValue($key, $value);
        }

        $stmt->bindValue(":limit", (int)$limit, PDO::PARAM_INT);
        $stmt->bindValue(":offset", (int)$offset, PDO::PARAM_INT);

        $stmt->execute();

        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    /**
     * Şirkete göre kullanıcı sayısını getirme
     *
     * @param int $company_id Şirket ID
     * @return int Kullanıcı sayısı
     */
    public function countUsersByCompany($company_id) {
        // SQL sorgusu
        $query = "SELECT COUNT(*) as total FROM " . $this->table_name . "
              WHERE company_id = :company_id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametre bağlama
        $stmt->bindParam(":company_id", $company_id);

        // Sorguyu çalıştırma
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);

        // Toplam sayıyı döndürme
        return (int)$row['total'];
    }

    /**
     * Toplam kullanıcı sayısını getirme
     *
     * @param string $search Arama kelimesi
     * @return int Kullanıcı sayısı
     */

    public function countUsers($search = null) {
        $query = "SELECT COUNT(*) as total FROM " . $this->table_name;

        $params = [];

        if ($search) {
            $query .= " WHERE (username LIKE :search OR email LIKE :search OR full_name LIKE :search)";
            $search = "%{$search}%";
            $params[":search"] = $search;
        }

        $stmt = $this->conn->prepare($query);

        foreach ($params as $key => $value) {
            $stmt->bindValue($key, $value);
        }

        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);

        return (int)$row['total'];
    }
}
?>