<?php
/**
 * Araç işlemleri sınıfı
 */
class Vehicle {
    // Veritabanı bağlantısı ve tablo
    private $conn;
    private $table_name = "vehicles";

    // Araç özellikleri
    public $id;
    public $company_id;
    public $customer_id;
    public $brand_id;
    public $model_id;
    public $plate_number;
    public $vin_number;
    public $year;
    public $color;
    public $fuel_type;
    public $transmission;
    public $mileage;
    public $engine_size;
    public $engine_power;
    public $created_at;
    public $updated_at;

    /**
     * Sınıf başlatıcı
     *
     * @param PDO $db Veritabanı bağlantısı
     */
    public function __construct($db) {
        $this->conn = $db;
    }

    /**
     * Yeni araç oluşturma
     *
     * @return boolean İşlem başarılı mı
     */
    public function create() {
        // SQL sorgusu
        $query = "INSERT INTO " . $this->table_name . "
                  (company_id, customer_id, brand_id, model_id, plate_number, vin_number, 
                   year, color, fuel_type, transmission, mileage, engine_size, engine_power, created_at)
                  VALUES
                  (:company_id, :customer_id, :brand_id, :model_id, :plate_number, :vin_number, 
                   :year, :color, :fuel_type, :transmission, :mileage, :engine_size, :engine_power, NOW())";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $this->plate_number = htmlspecialchars(strip_tags($this->plate_number));
        $this->vin_number = htmlspecialchars(strip_tags($this->vin_number));
        $this->color = htmlspecialchars(strip_tags($this->color));
        $this->fuel_type = htmlspecialchars(strip_tags($this->fuel_type));
        $this->transmission = htmlspecialchars(strip_tags($this->transmission));
        $this->engine_size = htmlspecialchars(strip_tags($this->engine_size));
        $this->engine_power = htmlspecialchars(strip_tags($this->engine_power));

        // Parametreleri bağlama
        $stmt->bindParam(":company_id", $this->company_id);
        $stmt->bindParam(":customer_id", $this->customer_id);
        $stmt->bindParam(":brand_id", $this->brand_id);
        $stmt->bindParam(":model_id", $this->model_id);
        $stmt->bindParam(":plate_number", $this->plate_number);
        $stmt->bindParam(":vin_number", $this->vin_number);
        $stmt->bindParam(":year", $this->year);
        $stmt->bindParam(":color", $this->color);
        $stmt->bindParam(":fuel_type", $this->fuel_type);
        $stmt->bindParam(":transmission", $this->transmission);
        $stmt->bindParam(":mileage", $this->mileage);
        $stmt->bindParam(":engine_size", $this->engine_size);
        $stmt->bindParam(":engine_power", $this->engine_power);

        // Sorguyu çalıştırma
        if ($stmt->execute()) {
            $this->id = $this->conn->lastInsertId();
            return true;
        }

        return false;
    }

    /**
     * Aracı ID ile bulma
     *
     * @param int $id Araç ID
     * @return array|boolean Araç verileri veya başarısız ise false
     */
    public function readOne($id) {
        // SQL sorgusu
        $query = "SELECT v.*, b.brand_name, m.model_name,
              CONCAT(c.first_name, ' ', c.last_name) as customer_name
              FROM " . $this->table_name . " v
              LEFT JOIN car_brands b ON v.brand_id = b.id
              LEFT JOIN car_models m ON v.model_id = m.id
              LEFT JOIN customers c ON v.customer_id = c.id
              WHERE v.id = :id
              LIMIT 1";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // ID parametresini bağlama
        $stmt->bindParam(':id', $id);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Araç bulundu mu kontrol etme
        if ($stmt->rowCount() > 0) {
            // Araç verilerini alma
            return $stmt->fetch(PDO::FETCH_ASSOC);
        }

        return false;
    }

    /**
     * Araç bilgilerini güncelleme
     *
     * @return boolean İşlem başarılı mı
     */
    public function update() {
        // SQL sorgusu
        $query = "UPDATE " . $this->table_name . "
                  SET customer_id = :customer_id,
                      brand_id = :brand_id,
                      model_id = :model_id,
                      plate_number = :plate_number,
                      vin_number = :vin_number,
                      year = :year,
                      color = :color,
                      fuel_type = :fuel_type,
                      transmission = :transmission,
                      mileage = :mileage,
                      engine_size = :engine_size,
                      engine_power = :engine_power,
                      updated_at = NOW()
                  WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Verileri temizleme
        $this->plate_number = htmlspecialchars(strip_tags($this->plate_number));
        $this->vin_number = htmlspecialchars(strip_tags($this->vin_number));
        $this->color = htmlspecialchars(strip_tags($this->color));
        $this->fuel_type = htmlspecialchars(strip_tags($this->fuel_type));
        $this->transmission = htmlspecialchars(strip_tags($this->transmission));
        $this->engine_size = htmlspecialchars(strip_tags($this->engine_size));
        $this->engine_power = htmlspecialchars(strip_tags($this->engine_power));

        // Parametreleri bağlama
        $stmt->bindParam(":id", $this->id);
        $stmt->bindParam(":customer_id", $this->customer_id);
        $stmt->bindParam(":brand_id", $this->brand_id);
        $stmt->bindParam(":model_id", $this->model_id);
        $stmt->bindParam(":plate_number", $this->plate_number);
        $stmt->bindParam(":vin_number", $this->vin_number);
        $stmt->bindParam(":year", $this->year);
        $stmt->bindParam(":color", $this->color);
        $stmt->bindParam(":fuel_type", $this->fuel_type);
        $stmt->bindParam(":transmission", $this->transmission);
        $stmt->bindParam(":mileage", $this->mileage);
        $stmt->bindParam(":engine_size", $this->engine_size);
        $stmt->bindParam(":engine_power", $this->engine_power);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Araç silme
     *
     * @return boolean İşlem başarılı mı
     */
    public function delete() {
        // SQL sorgusu
        $query = "DELETE FROM " . $this->table_name . " WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // ID parametresini bağlama
        $stmt->bindParam(":id", $this->id);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Tüm araçları listeleme
     *
     * @param int $company_id Şirket ID
     * @param int $limit Limit
     * @param int $offset Offset
     * @param string $search Arama kelimesi
     * @param int $customer_id Müşteri ID filtresi
     * @param string $sort_by Sıralama alanı
     * @param string $sort_dir Sıralama yönü
     * @return array Araç listesi
     */
    public function getVehicles($company_id, $limit = 10, $offset = 0, $search = null, $customer_id = null, $sort_by = 'id', $sort_dir = 'DESC') {
        // SQL sorgusu
        $query = "SELECT v.id, v.plate_number, v.vin_number, v.year, v.mileage, v.fuel_type, v.transmission,
                  b.brand_name, m.model_name,
                  CONCAT(c.first_name, ' ', c.last_name) as customer_name
                  FROM " . $this->table_name . " v
                  LEFT JOIN car_brands b ON v.brand_id = b.id
                  LEFT JOIN car_models m ON v.model_id = m.id
                  LEFT JOIN customers c ON v.customer_id = c.id
                  WHERE v.company_id = :company_id";

        $params = [":company_id" => $company_id];

        // Arama parametresi
        if ($search) {
            $query .= " AND (v.plate_number LIKE :search 
                       OR v.vin_number LIKE :search 
                       OR b.brand_name LIKE :search
                       OR m.model_name LIKE :search
                       OR CONCAT(c.first_name, ' ', c.last_name) LIKE :search)";
            $search = "%{$search}%";
            $params[":search"] = $search;
        }

        // Müşteri filtresi
        if ($customer_id) {
            $query .= " AND v.customer_id = :customer_id";
            $params[":customer_id"] = $customer_id;
        }

        // Sıralama
        $query .= " ORDER BY v.{$sort_by} {$sort_dir}";

        // Limit ve offset
        $query .= " LIMIT :limit OFFSET :offset";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        foreach ($params as $key => $value) {
            $stmt->bindValue($key, $value);
        }

        $stmt->bindValue(":limit", (int)$limit, PDO::PARAM_INT);
        $stmt->bindValue(":offset", (int)$offset, PDO::PARAM_INT);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    /**
     * Toplam araç sayısını getirme
     *
     * @param int $company_id Şirket ID
     * @param string $search Arama kelimesi
     * @param int $customer_id Müşteri ID filtresi
     * @return int Araç sayısı
     */
    public function countVehicles($company_id, $search = null, $customer_id = null) {
        // SQL sorgusu
        $query = "SELECT COUNT(*) as total FROM " . $this->table_name . " v
                  LEFT JOIN car_brands b ON v.brand_id = b.id
                  LEFT JOIN car_models m ON v.model_id = m.id
                  LEFT JOIN customers c ON v.customer_id = c.id
                  WHERE v.company_id = :company_id";

        $params = [":company_id" => $company_id];

        // Arama parametresi
        if ($search) {
            $query .= " AND (v.plate_number LIKE :search 
                       OR v.vin_number LIKE :search 
                       OR b.brand_name LIKE :search
                       OR m.model_name LIKE :search
                       OR CONCAT(c.first_name, ' ', c.last_name) LIKE :search)";
            $search = "%{$search}%";
            $params[":search"] = $search;
        }

        // Müşteri filtresi
        if ($customer_id) {
            $query .= " AND v.customer_id = :customer_id";
            $params[":customer_id"] = $customer_id;
        }

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        foreach ($params as $key => $value) {
            $stmt->bindValue($key, $value);
        }

        // Sorguyu çalıştırma
        $stmt->execute();
        $row = $stmt->fetch(PDO::FETCH_ASSOC);

        // Toplam sayıyı döndürme
        return (int)$row['total'];
    }

    /**
     * Müşteriye ait araçları getirme
     *
     * @param int $customer_id Müşteri ID
     * @return array Araç listesi
     */
    public function getVehiclesByCustomer($customer_id) {
        // SQL sorgusu
        $query = "SELECT v.id, v.plate_number, CONCAT(b.brand_name, ' ', m.model_name, ' (', v.year, ')') as vehicle_name
                  FROM " . $this->table_name . " v
                  LEFT JOIN car_brands b ON v.brand_id = b.id
                  LEFT JOIN car_models m ON v.model_id = m.id
                  WHERE v.customer_id = :customer_id
                  ORDER BY v.id DESC";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametre bağlama
        $stmt->bindParam(":customer_id", $customer_id);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    /**
     * Plaka numarasının mevcut olup olmadığını kontrol etme
     *
     * @param string $plate_number Plaka numarası
     * @param int $exclude_id Hariç tutulacak araç ID (güncelleme için)
     * @return boolean Plaka numarası mevcut mu
     */
    public function isPlateNumberExists($plate_number, $exclude_id = null) {
        // SQL sorgusu
        $query = "SELECT id FROM " . $this->table_name . " WHERE plate_number = :plate_number";

        // Hariç tutulacak ID varsa
        if ($exclude_id) {
            $query .= " AND id != :exclude_id";
        }

        $query .= " LIMIT 1";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(":plate_number", $plate_number);

        if ($exclude_id) {
            $stmt->bindParam(":exclude_id", $exclude_id);
        }

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonucu kontrol etme
        return $stmt->rowCount() > 0;
    }

    /**
     * Şasi numarasının mevcut olup olmadığını kontrol etme
     *
     * @param string $vin_number Şasi numarası
     * @param int $exclude_id Hariç tutulacak araç ID (güncelleme için)
     * @return boolean Şasi numarası mevcut mu
     */
    public function isVinNumberExists($vin_number, $exclude_id = null) {
        // Şasi numarası boşsa kontrole gerek yok
        if (empty($vin_number)) {
            return false;
        }

        // SQL sorgusu
        $query = "SELECT id FROM " . $this->table_name . " WHERE vin_number = :vin_number";

        // Hariç tutulacak ID varsa
        if ($exclude_id) {
            $query .= " AND id != :exclude_id";
        }

        $query .= " LIMIT 1";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(":vin_number", $vin_number);

        if ($exclude_id) {
            $stmt->bindParam(":exclude_id", $exclude_id);
        }

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonucu kontrol etme
        return $stmt->rowCount() > 0;
    }

    /**
     * Araç markalarını getirme
     *
     * @return array Marka listesi
     */
    public function getBrands() {
        // SQL sorgusu
        $query = "SELECT id, brand_name, brand_logo 
                  FROM car_brands 
                  WHERE status = 'active'
                  ORDER BY brand_name ASC";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    /**
     * Markaya göre modelleri getirme
     *
     * @param int $brand_id Marka ID
     * @return array Model listesi
     */
    public function getModelsByBrand($brand_id) {
        // SQL sorgusu
        $query = "SELECT id, model_name, start_year, end_year 
                  FROM car_models 
                  WHERE brand_id = :brand_id AND status = 'active'
                  ORDER BY model_name ASC";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametre bağlama
        $stmt->bindParam(":brand_id", $brand_id);

        // Sorguyu çalıştırma
        $stmt->execute();

        // Sonuçları döndürme
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    }

    /**
     * Kilometre bilgisini güncelleme
     *
     * @param int $id Araç ID
     * @param int $mileage Yeni kilometre
     * @return boolean İşlem başarılı mı
     */
    public function updateMileage($id, $mileage) {
        // SQL sorgusu
        $query = "UPDATE " . $this->table_name . "
                  SET mileage = :mileage, updated_at = NOW()
                  WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(":id", $id);
        $stmt->bindParam(":mileage", $mileage);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }

    /**
     * Araç sahibini değiştirme
     *
     * @param int $id Araç ID
     * @param int $new_customer_id Yeni müşteri ID
     * @return boolean İşlem başarılı mı
     */
    public function changeOwner($id, $new_customer_id) {
        // SQL sorgusu
        $query = "UPDATE " . $this->table_name . "
                  SET customer_id = :customer_id, updated_at = NOW()
                  WHERE id = :id";

        // Sorguyu hazırlama
        $stmt = $this->conn->prepare($query);

        // Parametreleri bağlama
        $stmt->bindParam(":id", $id);
        $stmt->bindParam(":customer_id", $new_customer_id);

        // Sorguyu çalıştırma
        return $stmt->execute();
    }
}